import { isDate } from 'date-fns';

/**
 * @description 判断是否是时间戳
 * @param {number} 时间戳
 * @return {boolean}
 */
export const isTimestamp = (value) => {
  // 判断是否为数字
  if (typeof value !== 'number') return false;
  // 判断是否为合理的时间戳（大于0）
  if (value <= 0) return false;
  // 判断是否为Math.floor(value)，即是否为整数
  if (value !== Math.floor(value)) return false;
  // 判断是否为日期对象
  return isDate(new Date(value));
}

/**
 * @description 生成连续的数字
 * @param {number} start 起点数字  
 * @param {number} end 终点数字
 * @return {array} 
 */
export const generateNumberArray = (start, end) => {
  return Array.from(new Array(end + 1).keys()).slice(start);
}
